=======
Credits
=======

The project started with the Master internship of Bertrand Charpentier and
the PhD theses of Nathan de Lara and Quentin Lutz, under the supervision of Thomas Bonald at Télécom Paris,
Institut Polytechnique de Paris.

Development Lead
----------------

* Thomas Bonald <thomas.bonald@telecom-paris.fr>
* Marc Jeanmougin <marc.jeanmougin@telecom-paris.fr>
* Nathan de Lara <nathan.delara@telecom-paris.fr>
* Quentin Lutz <quentin.lutz@telecom-paris.fr>
* Tiphaine Viard <tiphaine.viard@telecom-paris.fr>

Contributors
------------

* Bertrand Charpentier
* Maximilien Danisch
* François Durand
* Alexandre Hollocou
* Fabien Mathieu
* Yohann Robert
* Julien Simonnet
* Alexis Barreaux
* Rémi Jaylet
* Victor Manach
* Pierre Pébereau
* Armand Boschin
* Tiphaine Viard
* Flávio Juvenal <flavio@vinta.com.br>
